Class: Wavefront::Cli::Alerts

Inherits:
Wavefront::Cli show all
Defined in:
lib/wavefront/cli/alerts.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Wavefront::Cli

#initialize, #load_profile

Constructor Details

This class inherits a constructor from Wavefront::Cli

Instance Attribute Details

#argumentsObject

Returns the value of attribute arguments.



24
25
26
# File 'lib/wavefront/cli/alerts.rb', line 24

def arguments
  @arguments
end

#optionsObject

Returns the value of attribute options.



24
25
26
# File 'lib/wavefront/cli/alerts.rb', line 24

def options
  @options
end

Instance Method Details

#format_result(result, format) ⇒ Object



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/wavefront/cli/alerts.rb', line 54

def format_result(result, format)
  #
  # Call a suitable method to display the output of the API call,
  # which is JSON.
  #
  case format
  when :ruby
    pp result
  when :json
    puts JSON.pretty_generate(JSON.parse(result))
  when :human
    puts humanize(JSON.parse(result))
  else
    raise "Invalid output format '#{format}'. See --help for more detail."
  end
end

#human_line(k, v) ⇒ Object



127
128
129
# File 'lib/wavefront/cli/alerts.rb', line 127

def human_line(k, v)
  ('%-22s%s' % [k, v]).rstrip
end

#human_line_additionalInformation(k, v) ⇒ Object



161
162
163
# File 'lib/wavefront/cli/alerts.rb', line 161

def human_line_additionalInformation(k, v)
  human_line(k, indent_wrap(v))
end

#human_line_alertStates(k, v) ⇒ Object



157
158
159
# File 'lib/wavefront/cli/alerts.rb', line 157

def human_line_alertStates(k, v)
  human_line(k, v.join(','))
end

#human_line_created(k, v) ⇒ Object



131
132
133
134
135
136
137
# File 'lib/wavefront/cli/alerts.rb', line 131

def human_line_created(k, v)
  #
  # The 'created' and 'updated' timestamps are in epoch
  # milliseconds
  #
  human_line(k, Time.at(v / 1000))
end

#human_line_hostsUsed(k, v) ⇒ Object



143
144
145
146
147
148
149
150
151
# File 'lib/wavefront/cli/alerts.rb', line 143

def human_line_hostsUsed(k, v)
  #
  # Put each host on its own line, indented. Does this by
  # returning an array.
  #
  return k unless v && v.is_a?(Array) && ! v.empty?
  v.sort!
  [human_line(k, v.shift)] + v.map {|el| human_line('', el)}
end

#human_line_metricsUsed(k, v) ⇒ Object



153
154
155
# File 'lib/wavefront/cli/alerts.rb', line 153

def human_line_metricsUsed(k, v)
  human_line_hostsUsed(k, v)
end

#human_line_updated(k, v) ⇒ Object



139
140
141
# File 'lib/wavefront/cli/alerts.rb', line 139

def human_line_updated(k, v)
  human_line_created(k, v)
end

#humanize(alerts) ⇒ Object



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/wavefront/cli/alerts.rb', line 95

def humanize(alerts)
  #
  # Selectively display alert information in an easily
  # human-readable format. I have chosen not to display certain
  # fields which I don't think are useful in this context. I also
  # wish to put the fields in order. Here are the fields I want, in
  # the order I want them.
  #
  row_order = %w(name created severity condition displayExpression
                 minutes resolveAfterMinutes updated alertStates
                 metricsUsed hostsUsed additionalInformation)

  # build up an array of lines then turn it into a string and
  # return it
  #
  # Most things get printed with the human_line() method, but some
  # data needs special handling. To do that, just add a method
  # called human_line_key() where key is something in row_order,
  # and it will be found.
  #
  x = alerts.map do |alert|
    row_order.map do |key|
      lm = "human_line_#{key}"
      if self.respond_to?(lm)
        self.method(lm.to_sym).call(key, alert[key])
      else
        human_line(key, alert[key])
      end
    end
  end
end

#indent_wrap(line, cols = 78, offset = 22) ⇒ Object



165
166
167
168
169
170
171
# File 'lib/wavefront/cli/alerts.rb', line 165

def indent_wrap(line, cols=78, offset=22)
  #
  # hanging indent long lines to fit in an 80-column terminal
  #
  line.gsub(/(.{1,#{cols - offset}})(\s+|\Z)/, "\\1\n#{' ' *
            offset}").rstrip
end

#runObject



26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/wavefront/cli/alerts.rb', line 26

def run
  raise 'Missing token.' if ! @options[:token] || @options[:token].empty?
  raise 'Missing query.' if arguments.empty?
  query = arguments[0].to_sym

  wfa = Wavefront::Alerting.new(@options[:token])
  valid_state?(wfa, query)
  valid_format?(@options[:format].to_sym)
  options = { host: @options[:endpoint] }

  if @options[:shared]
    options[:shared_tags] = @options[:shared].delete(' ').split(',')
  end

  if @options[:private]
    options[:private_tags] = @options[:private].delete(' ').split(',')
  end

  begin
    result = wfa.send(query, options)
  rescue
    raise 'Unable to execute query.'
  end

  format_result(result, @options[:format].to_sym)
  exit
end

#valid_format?(fmt) ⇒ Boolean

Returns:

  • (Boolean)


71
72
73
74
75
76
77
78
79
# File 'lib/wavefront/cli/alerts.rb', line 71

def valid_format?(fmt)
  fmt = fmt.to_sym if fmt.is_a?(String)

  unless Wavefront::Client::ALERT_FORMATS.include?(fmt)
    raise 'Output format must be one of: ' +
      Wavefront::Client::ALERT_FORMATS.join(', ') + '.'
  end
  true
end

#valid_state?(wfa, state) ⇒ Boolean

Returns:

  • (Boolean)


81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/wavefront/cli/alerts.rb', line 81

def valid_state?(wfa, state)
  #
  # Check the alert type we've been given is valid. There needs to
  # be a public method in the 'alerting' class for every one.
  #
  s = wfa.public_methods(false).sort
  s.delete(:token)
  unless s.include?(state)
    raise 'State must be one of: ' + s.each { |q| q.to_s }.join(', ') +
      '.'
  end
  true
end